==> de.flapdoodle.embed.mongo-2.0.0-sources.jar: de/flapdoodle/embed/mongo/MongoRestoreStarter.java <==
/**
 * Copyright (C) 2011
 *   Can Yaman <can@yaman.me>
 *   Michael Mosmann <michael@mosmann.de>
 *   Martin Jöhren <m.joehren@googlemail.com>
 *
 * with contributions from
 * 	konstantin-ba@github,Archimedes Trajano	(trajano@github)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.flapdoodle.embed.mongo;

import de.flapdoodle.embed.mongo.config.IMongoRestoreConfig;
import de.flapdoodle.embed.mongo.config.RuntimeConfigBuilder;
import de.flapdoodle.embed.process.config.IRuntimeConfig;
import de.flapdoodle.embed.process.distribution.Distribution;
import de.flapdoodle.embed.process.extract.IExtractedFileSet;
import de.flapdoodle.embed.process.runtime.Starter;

public class MongoRestoreStarter extends Starter<IMongoRestoreConfig,MongoRestoreExecutable,MongoRestoreProcess> {

    private MongoRestoreStarter(IRuntimeConfig config) {
        super(config);
    }

    public static MongoRestoreStarter getInstance(IRuntimeConfig config) {
        return new MongoRestoreStarter(config);
    }

    public static MongoRestoreStarter getDefaultInstance() {
        return getInstance(new RuntimeConfigBuilder().defaults(Command.MongoRestore).build());
    }

    @Override
    protected MongoRestoreExecutable newExecutable(IMongoRestoreConfig mongoRestoreConfig, Distribution distribution, IRuntimeConfig runtime, IExtractedFileSet files) {
        return new MongoRestoreExecutable(distribution, mongoRestoreConfig, runtime, files);
    }
}

==> de.flapdoodle.embed.mongo-2.1.1-sources.jar: de/flapdoodle/embed/mongo/MongoRestoreStarter.java <==
/**
 * Copyright (C) 2011
 *   Can Yaman <can@yaman.me>
 *   Michael Mosmann <michael@mosmann.de>
 *   Martin Jöhren <m.joehren@googlemail.com>
 *
 * with contributions from
 * 	konstantin-ba@github,Archimedes Trajano	(trajano@github)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.flapdoodle.embed.mongo;

import de.flapdoodle.embed.mongo.config.IMongoRestoreConfig;
import de.flapdoodle.embed.mongo.config.RuntimeConfigBuilder;
import de.flapdoodle.embed.process.config.IRuntimeConfig;
import de.flapdoodle.embed.process.distribution.Distribution;
import de.flapdoodle.embed.process.extract.IExtractedFileSet;
import de.flapdoodle.embed.process.runtime.Starter;

public class MongoRestoreStarter extends Starter<IMongoRestoreConfig,MongoRestoreExecutable,MongoRestoreProcess> {

    private MongoRestoreStarter(IRuntimeConfig config) {
        super(config);
    }

    public static MongoRestoreStarter getInstance(IRuntimeConfig config) {
        return new MongoRestoreStarter(config);
    }

    public static MongoRestoreStarter getDefaultInstance() {
        return getInstance(new RuntimeConfigBuilder()
                .defaults(Command.MongoRestore)
                .daemonProcess(false)
                .build());
    }

    @Override
    protected MongoRestoreExecutable newExecutable(IMongoRestoreConfig mongoRestoreConfig, Distribution distribution, IRuntimeConfig runtime, IExtractedFileSet files) {
        return new MongoRestoreExecutable(distribution, mongoRestoreConfig, runtime, files);
    }
}
